@@ -1,8 +1,7 @@
 """Default settings."""
 
-DEFAULT_CONFIGFILE_NAME = "tapshex.yaml"
-DEFAULT_HIDDEN_CONFIGFILE_NAME = ".tapshexrc"
-DEFAULT_CONFIG_YAML = """# tapshex config file (YAML format)
+DEFAULT_CONFIGFILE = "tapshex.yaml"
+DEFAULT_CONFIGYAML = """# tapshex config file (YAML format)
 
 # See https://tapshex.readthedocs.io/en/latest/config/
 # for advanced configuration options
@@ -21,11 +20,4 @@ prefixes:
     "skosxl:":  "http://www.w3.org/2008/05/skos-xl#"
     "wdt:":     "http://www.wikidata.org/prop/direct/"
     "xsd:":     "http://www.w3.org/2001/XMLSchema#"
-
-extra_value_node_types:
-- nonliteral
-
-element_aliases:
-    "mand": "mandatory"
-    "rep": "repeatable"
 """
